@@ -1,6 +1,7 @@
 # SPDX-License-Identifier: MIT
 
-import sys
+
+from importlib import metadata
 
 import pytest
 
@@ -8,12 +9,6 @@ import attr
 import attrs
 
 
-if sys.version_info < (3, 8):
-    import importlib_metadata as metadata
-else:
-    from importlib import metadata
-
-
 @pytest.fixture(name="mod", params=(attr, attrs))
 def _mod(request):
     return request.param
